@@ -42,4 +42,8 @@ void rfc2822_header_printf
 void rfc2822_header_utf8_printf
 	(string_t *header, const char *name, const char *fmt, ...) ATTR_FORMAT(3, 4);
 
+void rfc2822_header_write_address(string_t *header,
+	const char *name, const char *address);
+
+
 #endif /* __RFC2822_H */
