@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2016 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_RUNTIME_H
@@ -14,7 +14,7 @@ struct sieve_runtime_env {
 	/* Interpreter */
 	struct sieve_instance *svinst;
 	struct sieve_interpreter *interp;
-	enum sieve_runtime_flags flags;
+	enum sieve_execute_flags flags;
 	struct sieve_error_handler *ehandler;
 
 	/* Executing script */
